"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const utils_1 = require("../shared/utils");
const snippetsApi_1 = require("../data/snippetsApi");
const lodash_1 = require("lodash");
exports.default = {
    register: (context) => {
        let disposable = vscode.commands.registerCommand("codesnippets.export-selection", () => __awaiter(this, void 0, void 0, function* () {
            // The code you place here will be executed every time your command is executed
            let token = yield utils_1.getToken(context);
            if (!token) {
                vscode.window.showErrorMessage("Unable to get your CodeSnippets.dev access token");
                return;
            }
            let editor = vscode.window.activeTextEditor || null;
            if (editor && editor.document) {
                let selectedCode = utils_1.getSelectedCode(editor);
                if (!selectedCode) {
                    vscode.window.showErrorMessage("Whoops! You don't have any code selected");
                    return;
                }
                let language = utils_1.getLanguage(editor);
                let collectionsPromise = snippetsApi_1.getMyCollections(token);
                let title = yield getTitle();
                let collection = yield getCollection(collectionsPromise);
                let tagsString = yield getTags();
                let filename = lodash_1.kebabCase(title) + utils_1.getCurrentFileExtension(editor);
                vscode.window.showInformationMessage("Creating new Snippet...");
                yield snippetsApi_1.saveSnippet(token, {
                    title,
                    collection,
                    tagsString,
                    filename,
                    language,
                    code: selectedCode,
                });
                vscode.window.showInformationMessage("Success!");
            }
        }));
        context.subscriptions.push(disposable);
    },
};
const getCollection = function (collectionsPromise) {
    return __awaiter(this, void 0, void 0, function* () {
        let collections = yield collectionsPromise;
        let options = collections.map((collection) => ({
            key: collection,
            label: collection,
        }));
        options.unshift({
            key: "create_new",
            label: "Create New...",
        });
        let selected = yield vscode.window.showQuickPick(options, {
            placeHolder: "Choose a collection",
        });
        if (selected.key === "create_new") {
            selected.key = yield vscode.window.showInputBox({
                prompt: "Enter a collection name",
            });
        }
        return selected.key;
    });
};
const getTitle = function () {
    return vscode.window.showInputBox({
        prompt: "Snippet Title",
    });
};
const getTags = function () {
    return vscode.window.showInputBox({
        prompt: "Enter tags",
        placeHolder: "react, utilities, secretsauce",
    });
};
//# sourceMappingURL=exportSelection.js.map