"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const utils_1 = require("../shared/utils");
const snippetsApi_1 = require("../data/snippetsApi");
const path = require("path");
const fs = require("fs-extra");
exports.default = {
    register: (context) => {
        let disposable = vscode.commands.registerCommand("codesnippets.import-file", (fileContext) => __awaiter(this, void 0, void 0, function* () {
            try {
                // The code you place here will be executed every time your command is executed
                let token = yield utils_1.getToken(context);
                if (!token)
                    vscode.window.showErrorMessage("Unable to get your CodeSnippets.dev access token");
                let editor = vscode.window.activeTextEditor || null;
                let selectedSnippets = yield utils_1.selectSnippets(token, { canPickMany: true });
                console.log(selectedSnippets);
                for (let i = 0; i < selectedSnippets.length; i++) {
                    console.log("HERE!!!");
                    yield saveSnippetFile(token, selectedSnippets[i].path, editor, fileContext);
                }
            }
            catch (err) {
                console.log("ERROR!!");
                console.log(err);
                vscode.window.showErrorMessage("Something went wrong!");
            }
        }));
        context.subscriptions.push(disposable);
    },
};
function saveSnippetFile(token, snippetPath, editor, fileContext) {
    return __awaiter(this, void 0, void 0, function* () {
        console.log("HERE!", token, snippetPath);
        let snippet = yield snippetsApi_1.getSnippet(token, snippetPath);
        console.log("Snippet!", snippet);
        if (snippet) {
            let defaultUri = getFileUri(editor, fileContext, snippet.filename);
            let saveResult = yield vscode.window.showSaveDialog({ defaultUri });
            fs.outputFileSync(saveResult.fsPath, snippet.code);
            vscode.window.showInformationMessage("CodeSnippets: Created " + saveResult.fsPath);
            return true;
        }
        else {
            vscode.window.showErrorMessage("Unable to create file from Snipppet", snippetPath);
            return null;
        }
    });
}
const getFileUri = function (editor, fileContext, filename) {
    let filepath = vscode.workspace.rootPath;
    if (fileContext) {
        let parsedContext = path.parse(fileContext.fsPath);
        filepath = parsedContext.ext.indexOf(".") === 0 ? parsedContext.dir : fileContext.fsPath;
    }
    else if (editor && editor.document) {
        filepath = path.join(editor.document.fileName, "..");
    }
    filepath = path.join(filepath, filename);
    return vscode.Uri.file(filepath);
};
//# sourceMappingURL=importFile.js.map