"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
let { request, GraphQLClient } = require("graphql-request");
const { orderBy, kebabCase } = require("lodash");
// const GRAPHQL_ENDPOINT = "http://localhost:5000/devcodesnippetsdotdev/us-central1/graphql";
const GRAPHQL_ENDPOINT = "https://us-central1-codesnippetsdotdev.cloudfunctions.net/graphql";
exports.getSnippet = function (token, path) {
    return __awaiter(this, void 0, void 0, function* () {
        let query = `{
		snippet(path:"${path}") {
			key
			filename
            code
            title
            language {
                key
            }
		}
  }`;
        const client = createGraphQLClient(token);
        return client.request(query).then((data) => data.snippet);
    });
};
exports.getMyCollections = function (token) {
    return __awaiter(this, void 0, void 0, function* () {
        const QUERY = `query GetMyCollections{
    me {
      collections {
        name
      }
    }
  }`;
        const client = createGraphQLClient(token);
        let collections = yield client.request(QUERY).then((data) => data.me.collections);
        return orderBy(collections, "name").map((c) => c.name);
    });
};
const SAVE_MUTATION = `mutation SaveSnippet($snippet: SaveSnippetInput!) {
  saveSnippet(snippet: $snippet) {
    key
    title
    path
  }
}`;
// Make a request everytime, but do it in the background if there is a cached list already
exports.saveSnippet = function (token, snippet) {
    return __awaiter(this, void 0, void 0, function* () {
        const client = createGraphQLClient(token);
        let result = yield client.request(SAVE_MUTATION, { snippet }).then((data) => data.saveSnippet);
        console.log("RESULT!!!", result);
        return result;
    });
};
exports.getSnippets = function (token, filter = {}, includeCode = false) {
    return __awaiter(this, void 0, void 0, function* () {
        const QUERY = `query GetMySnippets($filter: SnippetFilter) {
      me {
          snippets(filter: $filter) {
            key
            filename
            collection
            title
            description
            path
            tags {
                key
            }
            modified
            ${includeCode ? "code" : ""}
            createdBy {
                key
                username
            }
          }
      }
	}`;
        const client = createGraphQLClient(token);
        let snippets = yield client.request(QUERY, { filter }).then((data) => data.me.snippets);
        return orderBy(snippets, "title");
    });
};
const createGraphQLClient = (token) => new GraphQLClient(GRAPHQL_ENDPOINT, {
    headers: {
        Authorization: "Bearer " + token,
    },
});
//# sourceMappingURL=snippetsApi.js.map